"use strict";

exports.__esModule = true;
exports["default"] = void 0;
var _react = _interopRequireWildcard(require("react"));
var _hoistNonReactStatics = _interopRequireDefault(require("hoist-non-react-statics"));
var _getDisplayName = _interopRequireDefault(require("../utils/getDisplayName"));
var _I13nContext = _interopRequireDefault(require("../components/core/I13nContext"));
var _useI13nNode2 = _interopRequireDefault(require("../hooks/useI13nNode"));
var _useReactI13nRoot2 = _interopRequireDefault(require("../hooks/useReactI13nRoot"));
var _excluded = ["children", "i13nModel", "isLeafNode"];
/**
 * Copyright 2015 - Present, Yahoo Inc.
 * Copyrights licensed under the New BSD License. See the accompanying LICENSE file for terms.
 */
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var debugLib = require('debug');
var debug = debugLib('ReactI13n');

/**
 * Create an app level component with i13n setup
 * @param {Object} Component the root level component
 *
 * @param {Object} options passed into ReactI13n
 * @param {Boolean} options.isViewportEnabled if enable viewport checking
 * @param {Object} options.displayName display name of the wrapper component
 * @param {Object} options.i13nNodeClass the i13nNode class, you can inherit it with your own functionalities
 * @param {Object} options.rootModelData model data of root i13n node
 * @param {Boolean} options.skipUtilFunctionsByProps true to prevent i13n util function to be passed via props.i13n
 *
 * @param {Array} plugins plugins
 * @method setupI13n
 */
function setupI13n(Component, options, plugins) {
  if (options === void 0) {
    options = {};
  }
  if (plugins === void 0) {
    plugins = [];
  }
  if (!plugins.length) {
    debug('no plugins provided');
  }
  var _options = options,
    displayName = _options.displayName,
    skipUtilFunctionsByProps = _options.skipUtilFunctionsByProps;
  var RootI13nComponent = function RootI13nComponent(props) {
    var children = props.children,
      i13nModel = props.i13nModel,
      isLeafNode = props.isLeafNode,
      restProps = _objectWithoutPropertiesLoose(props, _excluded);
    var isPluginsInitialized = (0, _react.useRef)(false);
    var _useReactI13nRoot = (0, _useReactI13nRoot2["default"])(options),
      reactI13n = _useReactI13nRoot.i13nInstance,
      executeEvent = _useReactI13nRoot.executeI13nEvent;
    var initializeReactI13n = function initializeReactI13n() {
      if (reactI13n && !isPluginsInitialized.current) {
        plugins.forEach(function (plugin) {
          reactI13n.plug(plugin);
        });
        reactI13n.createRootI13nNode();
        isPluginsInitialized.current = true;
      }
    };
    // initial
    initializeReactI13n();

    // Update plugins if reactI13n instance changes
    (0, _react.useEffect)(function () {
      isPluginsInitialized.current = false;
      initializeReactI13n();
      return function () {
        isPluginsInitialized.current = false;
        reactI13n === null || reactI13n === void 0 ? void 0 : reactI13n.cleanUpPlugins();
      };
    }, [reactI13n]);
    var parentI13nNode = reactI13n === null || reactI13n === void 0 ? void 0 : reactI13n.getRootI13nNode();
    var _useI13nNode = (0, _useI13nNode2["default"])({
        i13nInstance: reactI13n,
        i13nModel: i13nModel,
        isLeafNode: isLeafNode,
        parentI13nNode: parentI13nNode
      }),
      i13nNode = _useI13nNode.i13nNode;
    var contextValue = (0, _react.useMemo)(function () {
      return {
        executeEvent: executeEvent,
        i13nInstance: reactI13n,
        i13nNode: i13nNode,
        parentI13nNode: parentI13nNode
      };
    }, [executeEvent, reactI13n, i13nNode, parentI13nNode]);
    return /*#__PURE__*/_react["default"].createElement(_I13nContext["default"].Provider, {
      value: contextValue
    }, /*#__PURE__*/_react["default"].createElement(Component, _extends({}, restProps, {
      i13n: !skipUtilFunctionsByProps ? contextValue : undefined
    }), children));
  };
  RootI13nComponent.displayName = displayName || "RootI13n" + (0, _getDisplayName["default"])(Component);
  (0, _hoistNonReactStatics["default"])(RootI13nComponent, Component);
  return RootI13nComponent;
}
var _default = setupI13n;
exports["default"] = _default;