"use strict";

exports.__esModule = true;
exports["default"] = void 0;
var _react = require("react");
var _reactDom = require("react-dom");
var _subscribeUiEvent = require("subscribe-ui-event");
var _variables = require("../utils/variables");
var _clickHandler = _interopRequireDefault(require("../libs/clickHandler"));
var _DebugDashboard = _interopRequireDefault(require("../libs/DebugDashboard"));
var _I13nNode = _interopRequireDefault(require("../core/I13nNode"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; } /**
                                                                                                                                                                                     * Copyright 2015 - Present, Yahoo Inc.
                                                                                                                                                                                     * Copyrights licensed under the New BSD License. See the accompanying LICENSE file for terms.
                                                                                                                                                                                     */
var DEFAULT_SCAN_TAGS = ['a', 'button'];

/**
 * Scan matched tags and
 * 1. create i13n node
 * 2. bind the click event
 * 3. fire created event
 * 4. (if enabled) create debug node for it
 */
var useScanLinks = function useScanLinks(_ref) {
  var enabled = _ref.enabled,
    executeEvent = _ref.executeEvent,
    i13nInstance = _ref.i13nInstance,
    parentI13nNode = _ref.i13nNode,
    node = _ref.node,
    shouldFollowLink = _ref.shouldFollowLink,
    _ref$tags = _ref.tags,
    tags = _ref$tags === void 0 ? DEFAULT_SCAN_TAGS : _ref$tags;
  var _useState = (0, _react.useState)([]),
    subI13nComponents = _useState[0],
    setSubI13nComponents = _useState[1];
  if (!enabled) {
    return;
  }
  (0, _react.useEffect)(function () {
    var DOMNode = (0, _reactDom.findDOMNode)(node);
    if (!DOMNode) {
      return;
    }
    var foundElements = [];

    // find all links
    tags.forEach(function (tagName) {
      var collections = DOMNode.getElementsByTagName(tagName);
      if (collections) {
        foundElements = foundElements.concat(_toConsumableArray(collections));
      }
    });

    // for each link
    // 1. create a i13n node
    // 2. bind the click event
    // 3. fire created event
    // 4. (if enabled) create debug node for it
    var newSubI13nComponents = foundElements.map(function (element) {
      var I13nNodeClass = i13nInstance.getI13nNodeClass() || _I13nNode["default"];
      var subI13nNode = new I13nNodeClass(parentI13nNode, {}, true, i13nInstance.isViewportEnabled());
      subI13nNode.setDOMNode(element);
      var handleClick = function handleClick(e) {
        (0, _clickHandler["default"])(e, {
          executeEvent: executeEvent,
          i13nNode: subI13nNode,
          props: {
            href: element.href,
            follow: true
          },
          shouldFollowLink: shouldFollowLink
        });
      };
      i13nInstance.execute('created', {
        i13nNode: subI13nNode
      });
      return {
        componentClickListener: (0, _subscribeUiEvent.listen)(element, 'click', handleClick),
        debugDashboard: _variables.IS_DEBUG_MODE ? new _DebugDashboard["default"](subI13nNode) : null,
        domElement: element,
        i13nNode: subI13nNode
      };
    });
    if (newSubI13nComponents) {
      setSubI13nComponents(newSubI13nComponents);
    }
    return function () {
      subI13nComponents.forEach(function (subI13nComponent) {
        var _subI13nComponent$com, _subI13nComponent$vie, _subI13nComponent$deb;
        subI13nComponent === null || subI13nComponent === void 0 ? void 0 : (_subI13nComponent$com = subI13nComponent.componentClickListener) === null || _subI13nComponent$com === void 0 ? void 0 : _subI13nComponent$com.remove();
        subI13nComponent === null || subI13nComponent === void 0 ? void 0 : (_subI13nComponent$vie = subI13nComponent.viewportDetector) === null || _subI13nComponent$vie === void 0 ? void 0 : _subI13nComponent$vie.unsubscribeAll();
        subI13nComponent === null || subI13nComponent === void 0 ? void 0 : (_subI13nComponent$deb = subI13nComponent.debugDashboard) === null || _subI13nComponent$deb === void 0 ? void 0 : _subI13nComponent$deb.destroy();
      });
    };
  }, [tags, node, parentI13nNode, shouldFollowLink]);
  return {
    subI13nComponents: subI13nComponents
  };
};
var _default = useScanLinks;
exports["default"] = _default;